class NoConnectionError(RuntimeError):
    """ No connection error """


class ObservationError(RuntimeError):
    """ Observation error """


class InvalidURLError(RuntimeError):
    """ Invalid URL Error """
